"""
CREATE TABLE Сотрудники (
    Табельный_номер INT PRIMARY KEY,
    ФИО TEXT NOT NULL,
    Отдел TEXT NOT NULL,
    Код_должности INT NOT NULL,
    Пол TEXT NOT NULL,
    Дата_рождения DATE NOT NULL,
    Стаж INT NOT NULL,
    Семейное_положение TEXT NOT NULL,
    Дети INT NOT NULL,
    FOREIGN KEY (Код_должности) REFERENCES Штатное_расписание(Код_должности)
);

CREATE TABLE Штатное_расписание (
    Код_должности INT PRIMARY KEY,
    Должность TEXT NOT NULL,
    Оклад INT NOT NULL
);

INSERT INTO Штатное_расписание (Код_должности, Должность, Оклад)
VALUES
    (1, 'Менеджер', 50000),
    (2, 'Инженер', 60000),
    (3, 'Программист', 70000);

INSERT INTO Сотрудники (Табельный_номер, ФИО, Отдел, Код_должности, Пол, Дата_рождения, Стаж, Семейное_положение, Дети)
VALUES
    (1, 'Иванов Иван Иванович', 'Отдел разработки', 3, 'М', '1985-03-15', 8, 'Ж', 2),
    (2, 'Петров Петр Петрович', 'Отдел продаж', 1, 'М', '1990-05-22', 3, 'Х', 0),
    (3, 'Сидорова Елена Владимировна', 'Отдел разработки', 2, 'Ж', '1982-12-07', 12, 'Б', 1),
    (4, 'Ковалева Мария Игоревна', 'Отдел продаж', 1, 'Ж', '1993-07-30', 2, 'Х', 0),
    (5, 'Григорьев Андрей Александрович', 'Отдел разработки', 3, 'М', '1987-11-09', 6, 'Ж', 3),
    (6, 'Николаев Дмитрий Викторович', 'Отдел продаж', 1, 'М', '1995-02-25', 1, 'Х', 0);
Запрос для выборки информации о сотрудниках с их зарплатами в рублях и долларах:
SELECT Сотрудники.Отдел, Сотрудники.ФИО, Штатное_расписание.Оклад*0.8+Штатное_расписание.Оклад AS Зарплата_руб, (Штатное_расписание.Оклад*0.8+Штатное_расписание.Оклад)/73 AS Зарплата_доллар
FROM Сотрудники INNER JOIN Штатное_расписание ON Сотрудники.Код_должности=Штатное_расписание.Код_должности ORDER BY Сотрудники.ФИО;
Запрос для вычисления средней заработной платы, количества женщин и детей по каждому подразделению:
SELECT Сотрудники.Отдел, AVG(Штатное_расписание.Оклад*0.8+Штатное_расписание.Оклад) AS Средняя_зарплата, SUM(IIF(Сотрудники.Пол='Ж',1,0)) AS Количество_женщин, SUM(Сотрудники.Дети) AS Количество_детей FROM Сотрудники INNER JOIN Штатное_расписание ON Сотрудники.Код_должности=Штатное_расписание.Код_должности GROUP BY Сотрудники.Отдел;
"""


class Node:
    def __init__(self, data):
        self.data = data
        self.next = None

class LinkedList:
    def __init__(self):
        self.head = None

    def append(self, data):
        new_node = Node(data)
        if not self.head:
            self.head = new_node
            return
        curr_node = self.head
        while curr_node.next:
            curr_node = curr_node.next
        curr_node.next = new_node

    def prepend(self, data):
        new_node = Node(data)
        new_node.next = self.head
        self.head = new_node

    def insert_after_node(self, prev_node, data):
        if not prev_node:
            print("Предыдущий узел отсутствует в списке")
            return
        new_node = Node(data)
        new_node.next = prev_node.next
        prev_node.next = new_node

    def delete_node(self, key):
        curr_node = self.head
        if curr_node and curr_node.data == key:
            self.head = curr_node.next
            curr_node = None
            return
        prev_node = None
        while curr_node and curr_node.data != key:
            prev_node = curr_node
            curr_node = curr_node.next
        if curr_node is None:
            return
        prev_node.next = curr_node.next
        curr_node = None

    def print_list(self):
        curr_node = self.head
        while curr_node:
            print(curr_node.data, end=" ")
            curr_node = curr_node.next

# Создание связного списка с вводом
linked_list = LinkedList()

n = int(input("Введите количество элементов: "))

for i in range(n):
    val = input(f"Введите значение {i+1}-го элемента: ")
    linked_list.append(val)

# Вывод списка
print("Список: ", end="")
linked_list.print_list()

# Добавление элемента в начало списка
val = input("\nВведите значение для добавления в начало списка: ")
linked_list.prepend(val)
print("Список после добавления в начало: ", end="")
linked_list.print_list()

# Добавление элемента после указанного узла
pos = int(input("\nВведите позицию для добавления элемента: "))
node = linked_list.head
for i in range(pos-1):
    node = node.next
val = input(f"Введите значение для добавления после элемента {node.data}: ")
linked_list.insert_after_node(node, val)
print("Список после добавления элемента: ", end="")
linked_list.print_list()

# Удаление элемента
val = input("\nВведите значение для удаления: ")
linked_list.delete_node(val)
print("Список после удаления элемента: ", end="")
linked_list.print_list()



class Product:
    def __init__(self, name, store, price):
        self.__name = name
        self.__store = store
        self.__price = price

    def get_name(self):
        return self.__name

    def get_store(self):
        return self.__store

    def get_price(self):
        return self.__price


class Warehouse:
    def __init__(self):
        self.__products = []

    def add_product(self, product):
        self.__products.append(product)

    def get_product_by_index(self, index):
        if index < len(self.__products):
            return self.__products[index]
        else:
            return None

    def get_product_by_name(self, name):
        for product in self.__products:
            if product.get_name() == name:
                return product
        return None

    def sort_by_store(self):
        self.__products.sort(key=lambda product: product.get_store())

    def sort_by_name(self):
        self.__products.sort(key=lambda product: product.get_name())

    def sort_by_price(self):
        self.__products.sort(key=lambda product: product.get_price())

    def __add__(self, other):
        total_price = 0
        for product in self.__products + other.__products:
            total_price += product.get_price()
        return total_price


# Создаем товары
product1 = Product("Книга", "Магазин книг", 500)
product2 = Product("Мышь", "Магазин компьютеров", 1500)
product3 = Product("Клавиатура", "Магазин компьютеров", 2000)

# Создаем склад и добавляем товары
warehouse = Warehouse()
warehouse.add_product(product1)
warehouse.add_product(product2)
warehouse.add_product(product3)

# Выводим информацию о товарах
print(warehouse.get_product_by_index(0).get_name())
print(warehouse.get_product_by_name("Мышь").get_price())

# Сортируем товары по названию магазина, по наименованию и по цене
warehouse.sort_by_store()
print([product.get_store() for product in warehouse._Warehouse__products])

warehouse.sort_by_name()
print([product.get_name() for product in warehouse._Warehouse__products])

warehouse.sort_by_price()
print([product.get_price() for product in warehouse._Warehouse__products])

# Выполняем сложение цен товаров на складах
warehouse2 = Warehouse()
warehouse2.add_product(Product("Наушники", "Магазин электроники", 1000))
print(warehouse + warehouse2)



import numpy as np
import matplotlib.pyplot as plt

# Определение диапазона значений параметра t
t_values = np.linspace(0, 5*np.pi, 500)

# Вычисление значений x и y
x = t_values * np.sin(t_values)
y = t_values * np.cos(t_values)

# Построение графика спирали
plt.plot(x, y)
plt.xlabel('x')
plt.ylabel('y')
plt.title('Спираль: x = t * sin(t), y = t * cos(t)')
plt.grid(True)
plt.show()



class Train:
    def __init__(self, destination, number, departure_time):
        self.__destination = destination
        self.__number = number
        self.__departure_time = departure_time

    def get_destination(self):
        return self.__destination

    def get_number(self):
        return self.__number

    def get_departure_time(self):
        return self.__departure_time

    def __lt__(self, other):
        return self.__departure_time < other.get_departure_time()

    def __str__(self):
        return f"Train {self.__number} to {self.__destination}, departs at {self.__departure_time}"


class TrainStation:
    def __init__(self):
        self.__trains = []

    def add_train(self, train):
        self.__trains.append(train)

    def get_train_by_number(self, number):
        for train in self.__trains:
            if train.get_number() == number:
                return train
        return None

    def get_trains_by_destination(self, destination):
        result = []
        for train in self.__trains:
            if train.get_destination() == destination:
                result.append(train)
        result.sort()
        return result

    def get_trains_departing_after(self, departure_time):
        result = []
        for train in self.__trains:
            if train.get_departure_time() > departure_time:
                result.append(train)
        result.sort()
        return result

    def __str__(self):
        result = []
        for train in self.__trains:
            result.append(str(train))
        return "\n".join(result)

# Пример использования классов
train1 = Train("Moscow", "123A", "08:00")
train2 = Train("St. Petersburg", "456B", "09:30")
train3 = Train("Kazan", "789C", "11:45")

station = TrainStation()
station.add_train(train1)
station.add_train(train2)
station.add_train(train3)

# Вывод информации о поезде по номеру с помощью индекса
print(station.get_train_by_number("123A"))

# Вывод информации о поездах, отправляющихся после введенного с клавиатуры времени
time = input("Enter departure time: ")
trains = station.get_trains_departing_after(time)
print("Trains departing after", time)
print("\n".join([str(train) for train in trains]))

# Перегруженная операция сравнения, выполняющая сравнение времени отправления двух поездов
print(train1 < train2)

# Вывод информации о поездах, отправляющихся в заданный пункт назначения. Информация должна быть отсортирована по времени отправления
destination = input("Enter destination: ")
trains = station.get_trains_by_destination(destination)
print("Trains to", destination)
print("\n".join([str(train) for train in trains]))



import numpy as np
import matplotlib.pyplot as plt


# Определение диапазонов переменных u и v
u_values = np.linspace(0, 3*np.pi, 100)
v_values = np.linspace(-np.pi, np.pi, 100)

# Создание сетки значений u и v
u, v = np.meshgrid(u_values, v_values)

# Вычисление значений x, y и z
x = u * np.cos(u) * (np.cos(v) + 1)
y = u * np.sin(u) * (np.cos(v) + 1)
z = u * np.sin(v)

# Построение 3D графика
fig = plt.figure()
ax = fig.add_subplot(111, projection='3d')
ax.plot_surface(x, y, z, cmap='viridis')
ax.set_xlabel('x')
ax.set_ylabel('y')
ax.set_zlabel('z')

# Отображение графика
plt.show()


"""
:author: GachiParty
"license: Apache License, Version 2.0, see LICENSE file

:copyright: (c) 2023 GachiParty
"""

from .bd1 import *
from .bd2 import *
from .oop1 import *
from .oop2 import *
from .prog1 import *
from .prog2 import *
from .prog3 import *
from .prog4 import *
from .prog5 import *
from .siaod1 import *
from .siaod2 import *

__author__ = 'GachiParty'
__version__ = '1.0a4'
__email__ = 'fetom30268@cutefier.com'


class Stack:
    def __init__(self):
        self.items = []

    def push(self, item):
        self.items.append(item)

    def pop(self):
        return self.items.pop()

    def is_empty(self):
        return len(self.items) == 0

    def peek(self):
        return self.items[-1]

    def size(self):
        return len(self.items)

s = Stack()
n = int(input("Введите количество элементов: "))
for i in range(n):
    elem = input(f"Введите элемент {i+1}: ")
    s.push(elem)

print("Удаление элемента: ", s.pop())
print("Получение верхнего элемента без удаления: ", s.peek())
print("Проверка на пустоту: ", s.is_empty())
print("Размер стека: ", s.size()) 



import numpy as np

# Генерация массива случайных чисел
arr = np.random.randint(1, 21, size=(5, 5))
print("Исходный массив:")
print(arr)

# Замена чисел от 3 до 8 на 0
arr[(arr >= 3) & (arr <= 8)] = 0
print("\nМассив после замены:")
print(arr)



import sqlite3

# Создание базы данных и таблицы для студентов
conn = sqlite3.connect('students.db')
cursor = conn.cursor()
cursor.execute('''CREATE TABLE IF NOT EXISTS students
                (id INTEGER PRIMARY KEY AUTOINCREMENT,
                 full_name TEXT,
                 address TEXT,
                 phone TEXT)''')
conn.commit()

# Функция для ввода информации о студентах
def input_student_data():
    full_name = input("Введите ФИО студента: ")
    address = input("Введите адрес студента: ")
    phone = input("Введите телефон студента: ")

    # Вставка данных в таблицу
    cursor.execute("INSERT INTO students (full_name, address, phone) VALUES (?, ?, ?)",
                   (full_name, address, phone))
    conn.commit()
    print("Данные студента успешно добавлены в базу данных.")

# Функция для вывода содержимого базы данных
def print_database_content():
    cursor.execute("SELECT * FROM students")
    rows = cursor.fetchall()

    if len(rows) > 0:
        print("Содержимое базы данных:")
        for row in rows:
            print("ID:", row[0])
            print("ФИО:", row[1])
            print("Адрес:", row[2])
            print("Телефон:", row[3])
            print("------------------")
    else:
        print("База данных пуста.")

# Использование функций для ввода данных и вывода содержимого базы данных
while True:
    print('Выберите действие:')
    print('1: Добавить нового студента')
    print('2: Вывести всех студентов')
    print('3: Завершить работу')
    inp = int(input())
    if inp != 1 and inp != 2 and inp != 3:
        print('Введено неверное действие')
    if inp == 1:
        input_student_data()
    if inp == 2:
        print_database_content()
    if inp == 3:
        conn.close()
        break



"""
-- Создание таблицы "Сотрудники"
CREATE TABLE Сотрудники (
  Табельный_номер INT PRIMARY KEY,
  ФИО TEXT,
  Отдел TEXT,
  Код_должности INT,
  Пол TEXT,
  Дата_рождения DATE,
  Стаж INT,
  Семейное_положение TEXT,
  Дети INT,
  FOREIGN KEY (Код_должности) REFERENCES Штатное_расписание (Код_должности)
);

-- Создание таблицы "Штатное расписание"
CREATE TABLE Штатное_расписание (
  Код_должности INT PRIMARY KEY,
  Должность TEXT,
  Оклад FLOAT
);

-- Заполнение таблиц
INSERT INTO Штатное_расписание (Код_должности, Должность, Оклад)
VALUES
    (1, 'Менеджер', 50000),
    (2, 'Инженер', 60000),
    (3, 'Программист', 70000);

INSERT INTO Сотрудники (Табельный_номер, ФИО, Отдел, Код_должности, Пол, Дата_рождения, Стаж, Семейное_положение, Дети)
VALUES
    (1, 'Иванов Иван Иванович', 'Отдел разработки', 3, 'М', '1985-03-15', 8, 'Ж', 2),
    (2, 'Петров Петр Петрович', 'Отдел продаж', 1, 'М', '1990-05-22', 3, 'Х', 0),
    (3, 'Сидорова Елена Владимировна', 'Отдел разработки', 2, 'Ж', '1982-12-07', 12, 'Б', 1),
    (4, 'Ковалева Мария Игоревна', 'Отдел продаж', 1, 'Ж', '1993-07-30', 2, 'Х', 0),
    (5, 'Григорьев Андрей Александрович', 'Отдел разработки', 3, 'М', '1987-11-09', 6, 'Ж', 3),
    (6, 'Николаев Дмитрий Викторович', 'Отдел продаж', 1, 'М', '1995-02-25', 1, 'Х', 0);


Запрос "Зарплата":
SELECT Сотрудники.ФИО, Штатное_расписание.Должность, Штатное_расписание.Оклад, 
IIF(Сотрудники.Стаж<=5, Штатное_расписание.Оклад*0.5, Штатное_расписание.Оклад)*2 AS Премия, 
(Штатное_расписание.Оклад+IIF(Сотрудники.Стаж<=5, Штатное_расписание.Оклад*0.5, Штатное_расписание.Оклад)) AS Зарплата
FROM Штатное_расписание INNER JOIN Сотрудники ON Штатное_расписание.Код_должности = Сотрудники.Код_должности;

Запрос "Отделы":
SELECT Сотрудники.Отдел, COUNT(Сотрудники.Табельный_номер) AS Количество_сотрудников,
MAX(Штатное_расписание.Оклад+IIF(Сотрудники.Стаж>5, Штатное_расписание.Оклад, Штатное_расписание.Оклад*0.5)) AS Максимальная_зарплата,
MIN(Штатное_расписание.Оклад+IIF(Сотрудники.Стаж<=5, Штатное_расписание.Оклад*0.5, Штатное_расписание.Оклад)) AS Минимальная_зарплата,
SUM(Сотрудники.Дети) AS Общее_количество_детей
FROM Сотрудники
INNER JOIN Штатное_расписание ON Сотрудники.Код_должности = Штатное_расписание.Код_должности
GROUP BY Сотрудники.Отдел;
"""



#!/usr/bin/env python

from io import open
from setuptools import setup

version = '1.0a4'

setup(
    name='pyGachi',
    author='GachiParty',

    version=version,
    author_email='fetom30268@cutefier.com',

    description=(
        u'Brat ne trogai, eto tibe ne nado'
    ),

    url='https://github.com/DANILYH/pyGachi',
    download_url='https://github.com/DANILYH/pyGachi/archive/v{}.zip'.format(
        version
    ),

    license='Apache License, Version 2.0, see LICENSE file',

    packages=['pyGachi'],
    install_requires=['aiohttp', 'aiofiles'],

    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Programming Language :: Python :: Implementation :: CPython',
    ]

)
